Monty Python's Flying Circus: Just the Words - Episode 12

# Episode Twelve

Falling from building
'Spectrum' - talking about things
Visitors from Coventry
Mr Hilter
The Minehead by-election
Police station (silly voices)
Upperclass Twit of the Year
Ken Shabby
How far can a minister fall?

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| 'It's' man
It's Man | It's...
| Opening animation.
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| CAPTION: 'EPISODES 17-26' CAPTION: 'THE NAKED ANT' CAPTION: 'A SIGNALBOX SOMEWHERE NEAR HOVE' Studio:
Voice Over | I know you're down there.
| Interior of a signalbox. A signalman (Terry J) stands by the signal levers. He is attacked by a bear. He wrestles it for 3.48 seconds. CAPTION: 'BUT IN AN OFFICE OFF THE GOSWELL ROAD' Two people seated opposite each other at a desk. Between them there is a large window. It appears that they are quite high up in a large office building. Every so often a body falls past the window. They are both working busily. After a pause a body drops past the window. First Man talks. Second Man hasn't noticed.
First Man | Hey, did you see that?
Second Man | Uhm?
First Man | Did you see somebody go past the window?
Second Man | What?
First Man | Somebody just went past the window. That way. (indicates down)
Second Man | (flatly) Oh. Oh.
| Second Man returns to his work. First Man looks for a little. As he starts to work again another body goes hurtling past the window.
First Man | Another one.
Second Man | Huh?
First Man | Another one just went past downwards.
Second Man | What?
First Man | Two people have just fallen out of that window to their almost certain death.
Second Man | Fine, fine. Fine.
First Man | Look! Two people (another falls) three people have just fallen past that window.
Second Man | Must be a board meeting.
First Man | Oh yeah. (another falls past) Hey. That was Wilkins of finance.
Second Man | Oh, no, that was Robertson.
First Man | Wilkins.
Second Man | Robertson.
First Man | Wilkins.
Second Man | Robertson.
| (Another falls.)
First Man | That was Wilkins.
Second Man | That was Wilkins. He was a good, good, er, golfer, Wilkins.
First Man | Very good golfer. Very good golfer. Rotten at finance. It'll be Parkinson next.
Second Man | Bet you it won't.
First Man | How much.
Second Man | What?
First Man | How much do you bet it won't? Fiver?
Second Man | All right.
First Man | Done.
Second Man | You're on.
First Man | Fine. (shakes; they look at the window) Come on Parky.
Second Man | Don't do it Parky.
First Man | Come on Parky. Jump Parky. Jump.
Second Man | Come on now be sensible Parky.
| Cut to letter.
Voice Over | Dear Sir, I am writing to complain about that sketch about people failing out of a high building. I have worked all my life in such a building and have never once.... arrgghhh (splat)
| Cut to film of man falling out of window. Cut back to set. First Man has hands in the air jubilantly.
First Man | Parkinson!
Second Man | Johnson!
| ANIMATION (possibly incorporating falling) which leads us ingeniously into: A presenter at a desk. Urgent current-affairs-type music. SUPERIMPOSED CAPTION: 'SPECTRUM'
Presenter | Good evening. Tonight 'Spectrum' looks at one of the major problems in the world today - that old vexed question of what is going on. Is there still time to confront it, let alone solve it, or is it too late? What are the figures, what are the facts, what do people mean when they talk about things? Alexander Hardacre of the Economic Affairs Bureau.
| Cut to equally intense pundit in front of a graph with three different coloured columns with percentages at the top. He talks with great authority.
Hardacre | In this graph, this column represents 23% of the population. This column represents 28% of the population, and this column represents 43% of the population.
| Cut back to presenter.
Presenter | Telling figures indeed, but what do they mean to you, what do they mean to me, what do they mean to the average man in the street? With me now is Professor Tiddles of Leeds University...
| Pull out to reveal bearded professor sitting next to presenter.
Presenter | ... Professor, you've spent many years researching into things, what do you think?
Professor | I think it's too early to tell.
| Cut to presenter, he talks even faster now.
Presenter | 'Too early to tell' ... too early to say... it means the same thing. The word 'say' is the same as the word 'tell'. They're not spelt the same, but they mean the same. It's an identical situation, we have with 'ship' and 'boat' (holds up signs saying 'ship' and 'boat') but not the same as we have with 'bow' and 'bough' (holds up signs), they're spelt differently, mean different things but sound the same. (he holds up signs saying 'so there') But the real question remains. What is the solution, if any, to this problem? What can we do? What am I saying? Why am I sitting in this chair? Why am I on this programme? And what am I going to say next? Here to answer this is a professional cricketer.
| Cut to cricketer.
Cricketer | I can say nothing at this point.
| Cut back to presenter.
Presenter | Well, you were wrong... Professor?
| Pull out to reveal professor still next to him.
Professor | Hello.
| Cut to close-up of presenter.
Presenter | Hello. So... where do we stand? Where do we stand? Where do we sit? Where do we come? Where do we go? What do we do? What do we say? What do we eat? What do we drink? What do we think? What do we do?
| Mix to stock film of London-Brighton train journey in two minutes. After a few seconds the train goes into a tunnel. Blackness. Loud crash. Cut to signalbox as before.
Signalman | (calling out of window) Sorry!
| He goes back to wrestling with bear. Cut to a small, tatty, little boarding house. SUPERIMPOSED CAPTION: 'A SMALL BOARDING HOUSE IN MINEHEAD, SOMERSET' Mr and Mrs Johnson, a typical holidaying bourgeois couple walk up to the front door and ring the bell. Inside the boarding house, the landlady goes up to the front door and opens it.
Landlady | Hello, Mr and Mrs Johnson?
Mr Johnson | That's right. Yes.
Landlady | Well come on in, excuse me not shaking hands, I've just been putting a bit of lard on the cat's boil.
Johnson | Very nice.
Landlady | Well you must be tired, it's a long way from Coventry, isn't it?
Johnson | Well, we usually reckon on five and a half hours and it took us six hours and fifty-three minutes, with the twenty-five minute stop at Frampton Cottrell to stretch our legs, only we had to wait half an hour to get onto the M5 at Droitwich.
Landlady | Really?
Johnson | Then there was a three mile queue just before Bridgewater on the A38. We usually come round on the B3339 just before Bridgewater, you see...
Landlady | Really?
Johnson | Ye, but this time we decided to risk it because they're always saying they're going to widen it there.
Landlady | Are they?
Johnson | Yes well just by the intersection, there where the A372 joins up, there's plenty of room to widen it there, there's only grass verges. They could get another six feet...knock down that hospital... Then we took the coast road through Williton and got all the Taunton traffic on the A358 from Crowcombe and Stogumber...
Landlady | Well you must be dying for a cup of tea.
Johnson | Well, wouldn't say no, not if it's warm and wet.
Landlady | Well come on in the lounge, I'm just going to serve afternoon tea.
Johnson | (following her into the lounge) Very nice.
| In the lounge are sitting another bourgeois couple Mr and Mrs Phillips.
Landlady | Come on in, Mr and Mrs Johnson, oh this is Mr and Mrs Phillips.
Mr Phillips | Good afternoon.
Johnson | Thank you.
Landlady | It's their third time here with us, we can't keep you away can we? Ha, ha, and over here is Mr Hilter.
| Landlady leads Mr and Mrs Johnson over to a table at which Adolf Hitler is sitting poring over a map. He is in full Nazi uniform. Himmler and Von Ribbentrop are also sitting at the table with him, Himmler in Nazi uniform and von Ribbentrop in evening dress, with an Iron Cross.
Hitler | Ach. Good time...good afternoon.
Landlady | Ooh planning a little excursion are we Mr Hilter?
Hitler | Ja, ja. We haff a little... (to others) Was ist rückweise bewegen?
Von Ribbentrop | Hike.
Himmler | Hiking.
Hitler | Ah yes, ve make a little hike for, for Bideford.
Johnson | (leaning over map) Oh well, you'll want the A39 then...no, no, you've got the wrong map there, this is Stalingrad, you want the Ilfracombe and Barnstaple section.
Hitler | Ah! Hein...Reginald you have the wrong map here you silly old leg-before-wicket English person.
Himmler | I'm sorry mein Fuhrer. I did not...(Hitler slaps him) Mein Dickie old chum.
Landlady | Lucky Mr Johnson pointed that out, eh? You wouldn't have had much fun in Stalingrad, would you...(they don't see the joke) I said, you wouldn't have had much fun in Stalingrad, would you, ha, ha, ha?
Hitler | (through clenched teeth) Not much fun in Stalingrad, no.
Landlady | Oh I'm sorry I didn't introduce you. This is Ron...Ron Vibbentrop.
Johnson | Oh, not Von Ribbentrop, eh?
Von Ribbentrop | (leaping two feet in the air, then realizing) Nein! Nein! Nein! Oh!! Ha, ha, ha.
Landlady | And this is the quiet one, Mr Bimmler - Heimlich Bimmler.
Himmler | How do you do there squire, also I am not Minehead lad but I in Peterborough, Lincolnshire was given birth to, but stay in Peterborough Lincolnshire house all during war, owing to nasty running sores, and was unable to go in the streets play football or go to Nürnberg. I am retired vindow cleaner and pacifist, without doing war crimes (hurriedly corrects himself) tch tch tch, and am glad England win World Cup - Bobby Charlton, Martin Peters - and eating lots of chips and fish and hole in the toads, and Dundee cakes on Piccadilly line. Don't you know old chap I was head of Gestapo for ten years. Five years! No, no, nein, I was not head of Gestapo at all...I make joke.
Landlady | Oooh, Mr Bimmler, you do have us on. (A telephone rings) Oh excuse me I must go and answer that. (leaves the room)
Johnson | How long are you down here for, Mr Hilter. Just the fortnight?
Hitler | (shouting) Why do you ask that? Are you a spy or something? (drawing revolver) Get over there against the wall Britischer pig, you're going to die!
| Von Ribbentrop og Himmler grab Hitler and calm him.
Himmler | Take it easy Dickie old chum.
Von Ribbentrop | I'm sorry Mr. Johnson, he's a bit on edge. He hasn't slept since 1945.
Hitler | Shut your cake hole you Nazi.
Von Ribbentrop | Cool it Führer cat!
Himmler | Ha, ha, ha. (laughing it off) The fun we have.
Johnson | Haven't I seen him on the television?
Von Ribbentrop and Himmler | Nicht. Nein. Nein, oh no.
Johnson | Television Doctor?
Von Ribbentrop | No!!! No!
| The landlady enters.
Landlady | Telephone, Mr Hilter, it's that nice Mr McGoering from the Bell and Compasses. He says he's found a place where you can hire bombers by the hour.
Hitler | If he opens his big mouth again...it's lampshade time!
Von Ribbentrop | (controlling Hitler and getting him towards the door) Shut up! (Hitler exits) Hire bombers by the hour, ha ha, what a laugh he is, that Scottish person. Good old Norman. (he exits)
Landlady | He's on the phone the whole time nowadays.
Johnson | In business is he?
Himmler | Soon baby!
Landlady | Of course it's his big day Thursday. Oh, they've been planning it for months.
Johnson | What's happens then?
Landlady | Well it's the North Minehead bye-election. Mr Hilter's standing as the National Bocialist candidate. He's got wonderful plans for Minehead.
Johnson | Like what?
Landlady | Well, for a start he wants to annex Poland.
Johnson | Oh, North Minehead's Conservative, isn't it?
Landlady | Well, they get a lot of people at their rallies.
Johnson | Rallies?
Landlady | Well, their Bocalist meetings, down at the Axis Café in Rosedale Road.
| Cut to a grotty Italian café. Sign above it read 'Axis Café, Italian Food a Specialty'. A figure clearly belonging to Mussolini is nailing up a sign or poster which reads: 'Vote for Hitler'. He looks around and goes into the café furtively. At this moment past the café come Hitler, Von Ribbentrop and Himmler on bikes. Hitler at the front shouting German through a megaphone. Von Ribbentrop at the back with a large banner 'Hilter for a better Meinhead'. Himmler in the middle with an old grammophone playing 'Deutschland Über Alles'. Cut to Hitler ranting in German on a balcony with Himmler at his side. Beneath them is a Nazi flag.
Hitler | I am not a racialist, but, und this is a big but, we in the National Bocialist Party believe das Überleben muss gestammen sein mit der schneaky Armstrong-Jones. Historische Taunton ist Volkermeinig von Meinhead.
Himmler | (stepping forward) Mr Hitler, Hilter, he says that historically Taunton is a part of Minehead already.
| Shot of a yokel looking disbelievingly at balcony. Von Ribbentrop appears behind.
Von Ribbentrop | He's right, do you know that?
| Meanwhile back on the balcony.
Hitler | (very exited) Und Bridgwater ist die letzte Fühlung das wir haben in Somerset!
| Over this we hear loud applause and 'Sieg Heils'. The yokel, who is not applauding, turns round rather surprised to see whence cometh the applause. He sees Von Ribbentrop operating a grammophone. Cut to vox pops.
Interviewer | (voice over) What do you think of Mr Hilter's politics.
Yokel | I don't like the sound of these 'ere boncentration bamps.
Pepperpot | Well, I gave him my baby to kiss and he bit it on the head.
Stockbroker | Well, I think he'd do a lot of good to the Stock Exchange.
Pepperpot | No...no...
Himmler | (thinly disguised as yokel) Oh yes Britischer pals he is wunderbar...ful. So.
Pepperpot | I think he's right about the coons, but then I'm a bit mental.
Gumby | I think he's got beautiful legs!
Madd | Well speaking as Conservative candidate I just drone on and on and on...never letting anyone else get a word in edgeways, until I start foaming at the mouth and fall over backwards. (he foams at the mouth and falls over backwards)
| Cut to 'Spectrum' studio: same presenter as before, sitting at desk.
Presenter | Foam at the mouth and fall over backwards. Is he foaming at the mouth to fall over backwards or falling over backwards to foam at the mouth. Tonight 'Spectrum' examines the whole question of frothing and falling, coughing and calling, screaming and bawling, walling and stalling, galling and mauling, palling and hauling, trawling and squalling and zalling. Zalling? Is there a word zalling? If there is what does it mean...if there isn't what does it mean? Perhaps both. Maybe neither. What do I mean by the word mean? What do I mean by the word word, what do I mean by what do I mean, what do I mean by do, and what do I do by mean? What do I do by do by do and what do I do by wasting your time like this? Goodnight.
| Cut to police station.
First Sergeant | (behind station counter into camera) Goodnight.
| Camera pulls back to show a man standing in front of the counter.
Man | Good evening, I wish to report a burglary.
First Sergeant | Speak up please, sir.
Man | I wish to report a burglary.
First Sergeant | I can't hear you, sir.
Man | (bellowing) I wish to report a burglary!
First Sergeant | That's a little bit too loud. Can you say it just a little less loud than that?
Man | (a little louder than normal) I wish to report a burglary.
First Sergeant | No... I'm still not getting anything... Er, could you try it in a higher register?
Man | What do you mean in a higher register?
First Sergeant | What?
Man | (in a high-pitched voice) I wish to report a burglary.
First Sergeant | Ahl That's it, hang on a moment. (gets out pencil and paper) Now a little bit louder.
Man | (louder and more high pitched) I wish to report a burglary.
First Sergeant | Report a what?
Man | (by now a ridiculously high-pitched squeak) Burglary!
First Sergeant | That's the exact frequency... now keep it there.
| Another sergeant enters and goes round to back of counter.
Second Sergeant | (in high-pitched voice) Hello, sarge!
First Sergeant | (in very deep voice) Evening Charlie.
| The second sergeant is taking his coat off, and the first one begins to pack up his papers. The man carries on with his tale of woe, but still in a high-pitched shriek.
Man | I was sitting at home with a friend of mine from Camber Sands, when we heard a noise in the bedroom. We went to investigate and found £5,000 stolen.
First Sergeant | Well, I'm afraid I'm going off duty now sir. Er, could you tell First Sergeant Foster?
| He leaves counter. Sergeant Foster comes forward with a helpful smile.
Man | (continues in high-pitched shriek) I was sitting at home with a friend of mine.
Second Sergeant | Excuse me sir, but, er, why the funny voice?
Man | (normal voice) Oh, terribly sorry. I'd just got used to talking like that to the other sergeant.
Second Sergeant | I'm terribly sorry... I can't hear you, sir, could you try speaking in a lower register?
Man | What! Oh (in a very deep voice) I wish to report the loss of £5,000.
Second Sergeant | £5,000? That's serious, you'd better speak to the detective inspector.
| At that moment, via the miracle of cueing, the detective inspector comes out of his office.
Inspector | (in very slow deep voice) What's the trouble, sergeant?
Second Sergeant | (speaking at fantastic speed) Well- this- gentleman- sir- has- just- come- in- to- report- that- he- was- sitting- at- home- with- a- friend- when- he- heard- a- noise- in- the- backroom- went- round- to- investigate- and- found- that-£5,000- in- savings- had- been- stolen.
Inspector | (deep voice) I see. (turns to man and addresses him in normal voice) Where do you live sir?
Man | (normal voice) 121, Halliwell Road, Dulwich, SE21
| The detective inspector has been straining to hear but has failed. The second sergeant comes in helpfully.
Second Sergeant | (fast) 121- Halliwell- Road- Dulwich- SE21
Inspector | (squeak) Another Halliwell Road job eh, sergeant?
First Sergeant | (fast) Yes- I- can't- believe- it- I- thought- the- bloke- who'd- done- that- was- put- inside- last- year.
Second Sergeant | (squeak) Yes, in Parkhurst.
First Sergeant | (deep) Well it must have been somebody else.
Inspector | (very deep) Thank you, sergeant. (normal voice to man) We'll get things moving right away, sir. (he picks up phone and dials, at the same time he shrieks in high voice to the tint sergeant) You take over here, sergeant (very deep voice to the second sergeant) Alert all squad cars in the area. (ridiculous sing-song voice into phone) Ha-allo Dar-ling, I'm afra-ID I sh-A-ll BE L-ate H-O-me this evening.
| Meanwhile the second sergeant has a radio-controlled microphone and is singing down it in fine operatic tenor.
Second Sergeant | (singing) Calling all squad cars in the area...
| Cut to vox pops.
Lovely Girl | (in deep male voice, dubbed on) I think that's in very bad taste.
Pig | (meows)
Giraffe | (barks)
President Nixon | (superimposed sheep bleating)
Upperclass Twit | Some people do talk in the most extraordinary way.
| Cut to Upperclass Twit of the Year sketch. The five competitors run onto the pitch.
Commentator | Good afternoon and welcome to Hurlingham Park. You join us just as the competitors are running out onto the field on this lovely winter's afternoon here, with the going firm underfoot and very little sign of rain. Well it certainly looks as though we're in for a splendid afternoon's sport in this the 127th Upperclass Twit of the Year Show. Well the competitors will be off in a moment so let me just identify for you. (close-up of the competitors) Vivian Smith-Smythe-Smith has an O-level in chemo-hygiene. Simon-Zinc-Trumpet-Harris, married to a very attractive table lamp. Nigel Incubator-Jones, his best friend is a tree, and in his spare time he's a stockbroker. Gervaise Brook-Hampster is in the Guards, and his father uses him as a wastepaper basket. And finally Oliver St John-Mollusc, Harrow and the Guards, thought by many to be this year's outstanding twit. Now they're moving up to the starting line, there's a jolly good crowd here today. Now they're under starter's orders ... and they're off! (the starter fires the gun; nobody moves) Ah no, they're not. No they didn't realize they were supposed to start. Never mind, we'll soon sort that out, the judge is explaining it to them now. I think Nigel and Gervaise have got the idea. All set to go. (starter fires gun again; the twits move off erratically) Oh, and they're off and it's a fast start this year. Oliver St John-Mollusc running a bit wide there and now they're coming into their first test, the straight line. (the twits make their way erratically along five white lines) They've got to walk along this straight line without failing over and Oliver's over at the back there, er, Simon's coming through quite fast on the outside, I think Simon and Nigel, both of them coming through very fast. There's Nigel there. No. Three, I'm sorry, and on the outside there's Gervaise coming through just out of shot and now, the position... (the twits approach a line of matchboxes piled three high) Simon and Vivian at the front coming to the matchbox jump.. three layers of matchboxes to clear... and Simon's over and Vivian's over beautifully, oh and the jump of a lifetime - if only his father could understand. Here's Nigel ... and now Gervaise is over he's, er, Nigel is over, and it's Gervaise, Gervaise is going to jump it, is it, no he's jumped the wrong way, there he goes, Nigel's over, beautifully. Now it's only Oliver. Oliver ... and Gervaise... oh bad luck. And now it's Kicking the Beggar. (the twits are kicking a beggar with a vending tray) Simon's there and he's putting the boot in, and not terribly hard, but he's going down and Simon can move on. Now Vivian's there. Vivian is there and waiting for a chance. Here he comes, oh a piledriver, a real piledriver, and now Simon's on No. l, Vivian 2, Nigel 3, Gervaise on 4 and Oliver bringing up the rear. Ah there's Oliver (Oliver is still trying to jump the matchboxes), there's Oliver now, he's at the back. I think he's having a little trouble with his old brain injury, he's going to have a go, no, no, bad luck, he's up, he doesn't know when he's beaten, this boy, he doesn't know when he's winning either. He doesn't have any sort of sensory apparatus. Oh there's Gervaise (He is still kicking the beggar) and he's putting the boot in there and he's got the beggar down and the steward's giving him a little bit of advice, yes, he can move on now, he can move on to the Hunt Photograph. He's off, Gervaise is there and Oliver's still at the back having trouble with the matchboxes. (the twits approach a table with two attractive girls and a photographer) Now here's the Hunt Ball Photograph and the first here's Simon, he's going to enjoy a joke with Lady Arabella Plunkett. She hopes to go into films, and Vivian's through there and, er, Nigel's there enjoying a joke with Lady Sarah Pencil Farthing Vivian Streamroller Adams Pie Biscuit Aftershave Gore Stringbottom Smith. (shot of twit in a sports car reversing into cut-out of old woman) And there's, there's Simon now in the sports car, he's reversed into the old woman, he's caught her absolutely beautifully. Now he's going to accelerate forward there to wake up the neighbour. There's Vivian I think, no Vivian's lost his keys, no there's Vivian, he's got the old woman, slowly but surely right in the midriff, and here he is. Here he is to wake up the neighbour now. (a man in bed in the middle of the pitch; twit slams car door repeatedly) Simon right in the lead, comfortably in the lead, but he can't get this neighbour woken up. He's slamming away there as best he can. He's getting absolutely no reaction at all. There, he's woken him up and Simon's through. Here comes Vivian, Vivian to slam the door, and there we are back at the Hunt Ball, I think that's Gervaise there, that's Gervaise going through there, and here, here comes Oliver, brave Oliver. Is he going to make it to the table, no I don't think he is, yes he is, (Oliver falls over the table) he did it, ohh. And the crowd are rising to him there,and there I can see, who is that there, yes that's Nigel, Nigel has woken the neighbour - my God this is exciting. Nigel's got very excited and he's going through and here comes Gervaise. Gervaise, oh no this is, er, out in the front there is Simon who is supposed to insult the waiter and he's forgotten. (Simon runs past a waiter standing with a tray) And Oliver has run himself over, (Oliver lying in front of car) what a great twit! And now here comes Vivian, Vivian to insult the waiter, and he is heaping abuse on him, and he is humiliating him, there and he's gone into the lead. Simon's not with him, no Vivian's in front of him at the bar. (the twits each have several goes at getting under a bar of wood five feet off the ground) Simon's got to get under this bar and this is extremely difficult as it requires absolutely expert co-ordination between mind and body. No Vivian isn't there. Here we go again and Simon's fallen backwards. Here's Nigel, he's tripped, Nigel has tripped, and he's under and Simon fails again, er, here is Gervaise, and Simon is through by accident. Here's Gervaise to be the last one over, there we are, here's Nigel right at the head of the field, (the twits approach five rabbits staked out on the ground; they fire at them with shotguns) and now he's going to shoot the rabbit, and these rabbits have been tied to the ground, and they're going to be a bit frisky, and this is only a one-day event. And they're blazing away there. They're not getting quite the results that they might, Gervaise is in there trying to bash it to death with the butt of his rifle, and I think Nigel's in there with his bare hands, but they're not getting the results that they might, but it is a little bit misty today and they must be shooting from a range of at least one foot. But they've had a couple of hits there I think, yes, they've had a couple of hits, and the whole field is up again and here they are. (they approach a line of shopwindow dummies each wearing only a bra) They're coming up to the debs, Gervaise first, Vivian second, Simon third. And now they've got to take the bras off from the front, this is really difficult, this is really the most, the most difficult part of the entire competition, and they're having a bit of trouble in there I think, they're really trying now and the crowd is getting excited, and I think some of the twits are getting rather excited too. (the twits are wreaking havoc on the dummies) Vivian is there, Vivian is coming through, Simon's in second place, and, no there's Oliver, he's not necessarily out of it. There goes Nigel, no he's lost something, and Gervaise running through to this final obstacle. (they approach a table with five revolvers laid out on it) Now all they have to do here to win the title is to shoot themselves. Simon has a shot. Bad luck, he misses. Nigel misses. Now there's Gervaise, and Gervaise has shot himself - Gervaise is Upperclass Twit of the Year. There's Nigel, he's shot Simon by mistake, Simon is back up and there's Nigel, Nigel's shot himself: Nigel is third in this fine and most exciting Upperclass Twit of the Year Show I've ever seen. Nigel's clubbed himself into fourth place. (three coffins on stand with medals) And so the final result: The Upperclass Twit of the Year - Gervaise Brook-Hampster of Kensington and Weybridge; runner up - Vivian Smith-Smythe-Smith of Kensington; and third - Nigel Incubator-Jones of Henley. Well there'll certainly be some car door slamming in the streets of Kensington tonight.
| Letter and voice over.
Voice Over | Dear Sir, how splendid it is to see the flower of British manhood wiping itself out with such pluck and tenacity. Britain need have no fear with leaders of this calibre. If only a few of the so-called working class would destroy themselves so sportingly. Yours etc., Brigadier Mainwaring Smith Smith Smith etc. Deceased etc. PS etc. Come on other ranks, show your stuff.
| ANIMATION:
Soldier | Yes Sir, I'll do my best, sir! (coughs)
Voice | (off) No, not good enough.
Soldier | (coughs again, his leg falls off)
Voice | No, still not good enough.
Soldier | (coughs again, he completely disintegrates)
First Voice | Yes, that's better.
| A hand picks up the animated bits and we see Terry J. stuffing them into a pipe. He puts the pipe down and various strange beasties climb out of it. Cartoon link into still a of beautiful country home. 'Hearts of Oak' -type music. The camera tracks into the house and mixes to: close-up of distinguished, noble father and gay, innocent beautiful daughter - a delicately beautiful English rose.
Father | Now I understand that you want to marry my daughter?
| Pull out to reveal that he is addressing a ghastly thing. A grubby, smelly, brown mackintoshed shambles, unshaven with a continuous hacking cough, and an obscene leer. He sits on the sofa in this beautiful elegant lounge.
Shabby | (sniffing and coughing) That's right ... yeah... yeah...
Father | Yes, you realize of course that Rosamund is still rather young?
Rosamund (Connie Booth) | Daddy you make me feel like a child. (she gazes at Shabby fondly)
Shabby | (lasciviously) Oh yeah ... you know... get 'em when they're young eh... eh! OOOOH! Know what I mean eh, oooh! (makes obscene gesture involving elbow)
Father | Well I'm sure you know what I mean, Mr ... er... Mr... er .. er?
Shabby | Shabby... Ken Shabby...
Father | Mr Shabby... I just want to make sure that you'll be able to look after daughter...
Shabby | Oh yeah, yeah. I'll be able to look after 'er all right sport, eh, know what I mean, eh emggh!
Father | And, er, what job do you do?
Shabby | I clean out public lavatories.
Father | Is there promotion involved?
Shabby | Oh yeah, yeah. (produces handkerchief and cleans throat horribly into it) After five years they give me a brush... eurggha eurgh ... I'm sorry squire, I've gobbed on your carpet...
Father | And, ah, where are you going to live?
Shabby | Well round at my gran's... she trains polecats, but most of them have suffocated so there should be a bit of spare room in the attic, eh. Know what I mean. Oooh!
Father | And when do you expect to get married?
Shabby | Oh, right away sport. Right away... you know... I haven't had it for weeks...
Father | Well look I'll phone the bishop and see if we can get the Abbey...
Shabby | Oh, diarrhoea. (coughing fit)
| Cut to strange PHOTO CAPTION SEQUENCE (to be worked out with Terry 'the sap' Gilliam) (if he can spare the time).
Voice Over | The story so far: Rosamund's father has become ensnared by Mr Shabby's extraordinary personal magnetism. Bob and Janet have eaten Mr Farquar's goldfish during an Oxfam lunch, and Mrs Elsmore's marriage is threatened by Doug's insistence that he is on a different level of consciousness. Louise's hernia has been confirmed, and Jim, Bob's brother, has run over the editor of the 'Lancet' on his way to see Jenny, a freelance Pagoda designer. On the other side of the continent Napoleon still broods over the smouldering remains of a city he had crossed half the earth to conquer...
| Mix from photo captions to studio. CAPTION: 'A CORNER OF A BED-SITTER' A girl in bra and pants goes over to television and switches it on.
Voice Over | ... whilst Mary, Roger's half-sister, settles down to watch television...
| On the screen comes the start of a Party Political Broadcast. CAPTION: 'A PARTY POLITICAL BROADCAST ON BEHALF OF THE WOOD PARTY'
Voice Over | There now follows a Party Political Broadcast on behalf of the Wood Party.
| Cut to a traditional grey-suited man at desk looking straight into camera. SUPERIMPOSED CAPTION: 'THE RT. HON. LAMBERT WARBECK'
Minister | Good evening. We in the Wood Party feel very strongly that the present weak drafting of the Local Government Bill leaves a lot to be desired, and we intend to fight.
| He thumps on the desk and he falls through the floor. (Yes Mr Director you did read that right: he fell through the floor and added a fortune to the budget). As he falls he emits a long scream, fading away slowly. Another man comes and looks down into the pit.
Man | Hello Helllllllllloooooooooo! (to camera) Er I, I'm afraid the minister's fallen through the Earth's crust. Er... excuse me a moment. (goes and looks at pit) Helloooo.
Minister | (unseen, a long way down) Helloooooo.
Man | Are you all right minister?
Minister | I appear to have landed on this kind of ledge thing.
Man | Shall we lower down one of the BBC ropes?
Minister | If you'd be so kind.
Man | What length of BBC rope will we be likely to need?
Minister | I should use the longest BBC rope. That would be a good idea I would imagine.
Man | Okey doke chief. Er, Tex get the longest BBC rope, and bring it here pronto.
Minister | (still a long way down) In the meantime, since I am on all channels, perhaps I'd better carry on with this broadcast by shouting about our housing plans from down here as best I can. Could someone throw me down a script. (man drops the script down and Tex appears with enormous coil of rope) The script would appear to have landed on a different ledge somewhat out of my grasp, don't you know.
Man | Er, well perhaps when the rope reaches you minister you could kind of swing over to the ledge and grab it.
Minister | Good idea.
| Cut to minister swinging on rope. CAPTION: 'THE RT. HON. LAMBERT WARBECK'
Minister | Well I'm going to carry on, if I can read the script.
| He swings over to a ledge opposite with a script on it. As he gets near he peers and starts reading.
Minister | Good evening. We in the Wood Party (he swings away and then back) feel very strongly about (swings away and back) the present weak drafting of the Local Government Bill and no, no - it's no good, it's not working.., I think I'll have to try and make a grab for it. Ah. There we are. (he swings over and grabs the script with one hand; he turns to camera and continues) Good evening. We in the Wood Party feel very strongly about the present (he makes a vigorous gesture and in so doing lets go of rope and slips so that he is now hanging upside down) agh, agh. Oh dear. Hello!
Man | (out of vision) Hello.
Minister | Look, look, I must look a bit of a chump hanging upside down like this.
Man | (out of vision) Don't worry minister. (cut to man looking off-camera) I think love if we turn the picture upside down we should help the minister, then.
| Cut to minister. The picture is now the other way up. The minister now appears to be the right way up.
Minister | Oh good. Look, er, I'm sorry about this, but there seem to be a few gremlins about... I think I'd better start from the beginning. Er, good evening, we in the Wood Party feel very strongly about, oh ... (he drops script) Bloody heck. Oh, oh dear, er terribly sorry about this, about saying bloody heck on all channels, but, er...
Man | (out of vision) There's another script on the way down minister.
Minister | Oh good, good. Well ... er... er... um... Good evening. Er ... well... er... how are you? Er... Oh yes look, I don't want you to think of the Wood Party as a load of old men that like hanging around on ropes only I ... er ... oh ... oh.
| Meanwhile a man, the right way up, has been lowered down to the minister. As the picture is reversed, he appears to be moving straight up towards him. The minister sees him.
Minister | Ah. Thank you. (taking script; the man on the rope starts to climb back up) Good evening, we in the Wood Party feel very strongly about the present weak drafting... (man falls past with a scream) Look. I think we'd better call it a day.
| Cut to two men at a desk in a discussion set.
First Robert | Is this the furthest distance that a minister has fallen? Robert.
| Cut to Robert.
Second Robert | Well surprisingly not. The Canadian Minister for External Affairs fell nearly seven miles during a Liberal Conference in Ottawa about six years ago, and then quite recently the Kenyan Minister for Agric. and Fish fell nearly twelve miles during a Nairobi debate in Parliament, although this hasn't been ratified yet.
First Robert | Er, how far did the Filipino cabinet fall last March?
Second Robert | Er, well they fell nearly thirty-nine miles but it's not really so remarkable as that was due to their combined weight, of course. Robert.
First Robert | Thank you, Robert. Well now what's your reaction to all this, Robert?
| Cut to third Robert who is staring intently into camera. He is wearing a fright wig and has a left eyebrow four inches above his right one.
Third Robert | Well, well Robert the main thing is that it's terribly exciting. You see the minister is quite clearly lodged between rocks we know terribly little of. Terribly little. Of course the main thing is we're getting colour pictures of an extraordinarily high quality. The important thing is, the really exciting thing is the minister will (as he gets more excited he starts to emit smoke) be bringing back samples of the Earth's core which will give us a tremendous, really tremendous tremendous tremendous clue about the origins of the Earth and what God himself is made of. (he bursts into fire and someone has to throw a buckets of water over him) Oh, oh I needed that.
| Cut back to first Robert.
First Robert | Thank you Robert. Well that seems to be about all we have time for tonight. Unless anyone has anything else to say. Has anyone anything else to say?
| Various 'noes' plus one 'bloody fairy' and more noes, from a very rapid montage of all the possible characters in this week's show saying 'no'. The last one we come to is the Spectrum presenter. He says more than no.
Presenter | What do we mean by no, what do we mean by yes, what do we mean by no, no, no. Tonight Spectrum looks at the whole question of what is no.
| The sixteen-ton weight falls on him. Cut to 'It's' man running away. CREDITS